%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Trade Reforms and Labor Market Adjustments
% Date: 2015/03/05
% Solve for steady state allocations
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% SETTING GVARS
setgvars;

%N       = 10;
%taus    = linspace(1,tau_max^(1/gvars.curv),N)'.^(gvars.curv);

N       	= 4;
tau_max 	= 1.667;
tau_med1 	= 1.534;
tau_med2 	= 1.250;%1.25
tau_min 	= 1.00;
taus 		= [tau_min, tau_med2, tau_med1, tau_max];

Qs      = zeros(N,1);
cH_maxs = zeros(N,1);
utils   = zeros(N,1);
cons0s  = zeros(N,1);
labor0s = zeros(N,1);
gs      = gvars;

parfor i   = 1:N
   gs(i)        = gvars;
   gs(i).tau    = taus(i);
   
   [Qs(i), cH_maxs(i)]      = h2hlewis(gs(i));
   utils(i)                 = util(Qs(i),cH_maxs(i),gs(i));
   [cons0s(i),labor0s(i)]   = cons0(Qs(i),cH_maxs(i),gs(i));
   fprintf('Done with loop iteration %g \n', i);
end

%% SOLUTIONS
fprintf('************************************* \n')
fprintf('*****   Main parameters   *********** \n')
fprintf('        H      = %g \n',gvars.H)
fprintf('        M      = %g \n',gvars.M)
fprintf('        delta  = %g \n',gvars.delta)
fprintf('        alpha  = %g \n',gvars.alpha)
fprintf('        lambda = %g \n',gvars.lambda)
fprintf('        kappa  = %g \n',gvars.kappa)
fprintf('        sigma  = %g \n',gvars.sigma)
fprintf('        markup = %g \n',gvars.markup)
fprintf('        rho    = %g \n',gvars.rho)
fprintf('        eta    = %g \n',gvars.eta)
fprintf('        gamma  = %g \n',gvars.gamma)
fprintf('        s      = %g \n',gvars.s)
fprintf('*****                     *********** \n')
fprintf('************************************* \n')
fprintf('\n\n')

fprintf('(    taus, gvars.markup > taus.^2, cH_maxs,   Qs ,   Us,  cons0s, labor0s) \n')
disp([(1:N)', taus', gvars.markup' > taus'.^2, cH_maxs, Qs, utils, cons0s, labor0s])

fprintf('(    taus,    cH_maxs,      Qs ,     Us,  cons0s,    labor0s) \n')
idx = [4,3,2,1];
disp([idx', taus(idx)', cH_maxs(idx), Qs(idx), utils(idx), cons0s(idx), labor0s(idx)])

%% PLOTS

plotgraphs = 1;
if plotgraphs
    ini         = 4;
    med2   		= 3;
    med1   		= 2;
    fin         = 1;
    to_plot 	= [ini,med2,med1,fin];
    plots_long_run
end