%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Trade Reforms and Labor Market Adjustments - Codes - v 2011/11/26
% Head-to-head with Lewis-like unemployment extending Helpman-Itskhoki
% Solve for steady state allocations + MEDIUM RUN ALLOCATION
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% SETTING GVARS + INITIAL & FINAL TARIFFS
setgvars;


%% Changes in Iceberg Transportation Cost
% tau_ini         = 1.0500;
% tau_ini         = 1.60;
tau_ini         = 1.11; %1.25;
% tau_fin         = 1.39;
tau_fin         = 1.00; %1.13;

%index
ini             = 1;
fin             = 3;
med             = 2;
N               = 3;

% adjusting the gvars
taus_trans      = ones(N,1);
taus_trans(ini) = tau_ini;
taus_trans(med) = tau_fin;
taus_trans(fin) = tau_fin;

gs_trans            = [gvars ; gvars ; gvars];
gs_trans(ini).tau   = taus_trans(ini);
gs_trans(fin).tau   = taus_trans(fin);
gs_trans(med).tau   = taus_trans(med);


%% COMPUTE LONG RUN EQUILIBRIA FOR EACH TARIFF

Qs_trans        = zeros(N,1);
cH_maxs_trans   = zeros(N,1);
utils_trans     = zeros(N,1);
cons0s_trans    = zeros(N,1);
labor0s_trans   = zeros(N,1);

for i   = [ini,fin]   
   [Qs_trans(i), cH_maxs_trans(i)]      = h2hlewis(gs_trans(i));
   utils_trans(i)                       = util(Qs_trans(i),...
                                            cH_maxs_trans(i),gs_trans(i));
   [cons0s_trans(i),labor0s_trans(i)]   = cons0(Qs_trans(i),...
                                            cH_maxs_trans(i),gs_trans(i));
   fprintf('Done with iteration %g for tau =  %g \n', i, taus_trans(i));
end


%% COMPUTING THE TRANSITION INCOME

[Qs_trans(med), cH_maxs_trans(med)]  = ...
    h2hlewis_trans(Qs_trans(ini),cH_maxs_trans(ini),gs_trans(ini),...
    gs_trans(med));

utils_trans(med)                       = ...
    util_trans(Qs_trans(med),cH_maxs_trans(med),Qs_trans(ini),....
    cH_maxs_trans(ini),...
    gs_trans(ini),gs_trans(med));
[cons0s_trans(med),labor0s_trans(med)]   = ...
    cons0_trans(Qs_trans(med),cH_maxs_trans(med),Qs_trans(ini),...
    cH_maxs_trans(ini),...
    gs_trans(ini),gs_trans(med));
                                        

%% SOLUTIONS
fprintf('************************************* \n')
fprintf('*****   Main parameters   *********** \n')
fprintf('        H      = %g \n',gvars.H)
fprintf('        M      = %g \n',gvars.M)
fprintf('        delta  = %g \n',gvars.delta)
fprintf('        alpha  = %g \n',gvars.alpha)
fprintf('        lambda = %g \n',gvars.lambda)
fprintf('        kappa  = %g \n',gvars.kappa)
fprintf('        sigma  = %g \n',gvars.sigma)
fprintf('        markup = %g \n',gvars.markup)
fprintf('        rho    = %g \n',gvars.rho)
fprintf('        eta    = %g \n',gvars.eta)
fprintf('        gamma  = %g \n',gvars.gamma)
fprintf('        s      = %g \n',gvars.s)
fprintf('*****                     *********** \n')
fprintf('************************************* \n')
fprintf('\n\n')

fprintf(['(taus_trans, cH_maxs_trans, Qs_trans, utils_trans,',...
    'cons0s_trans, labor0s_trans) \n'])
disp([taus_trans, cH_maxs_trans, Qs_trans , utils_trans, ...
    cons0s_trans, labor0s_trans])

%% GAIN/LOSS

loss = (utils_trans(fin) - utils_trans(med))/ ...
    (utils_trans(fin));

fprintf('Relative Util Loss is %9.2f pct. \n', loss*100)
fprintf('\n\n')

%% PLOTS

plotgraphs = 1;
if plotgraphs
    plots_trans
end

